/*
 * Copyright (c) 2010 by Intevation GmbH
 *
 * This program is free software under the LGPL (>=v2.1)
 * Read the file LGPL.txt coming with the software for details
 * or visit http://www.gnu.org/licenses/ if it does not exist.
 */

package de.intevation.gnv.state;

import java.util.Collection;
import java.util.List;

/**
 * The default implementation of <code>OutputMode</code>.
 *
 * @author <a href="mailto:tim.englich@intevation.de">Tim Englich</a>
 * @author <a href="mailto:ingo.weinzierl@intevation.de">Ingo Weinzierl</a>
 */
public class DefaultOutputMode implements OutputMode {

    /**
     * The UID of this Class.
     */
    private static final long serialVersionUID = -6459085460904827056L;
    private String name = null;
    private String description = null;
    private String mimeType = null;
    private Collection<InputValue> inputParameters = null;
    private List<ExportMode> exportModes;

    /**
     * Constructor
     *
     * @param name The name of the output mode.
     * @param description The description of this output mode.
     * @param mimeType The mime type used by this output mode.
     * @param inputParameters The input parameters required by this output mode.
     * @param exportModes The export modes for this output mode.
     */
    public DefaultOutputMode(
        String name,
        String description,
        String mimeType,
        Collection<InputValue> inputParameters,
        List<ExportMode> exportModes)
    {
        super();
        this.name            = name;
        this.description     = description;
        this.mimeType        = mimeType;
        this.inputParameters = inputParameters;
        this.exportModes     = exportModes;
    }

    /**
     * @return the description.
     */
    public String getDescription() {
        return this.description;
    }

    /**
     * @return the mime type.
     */
    public String getMimeType() {
        return this.mimeType;
    }

    /**
     * @return the name.
     */
    public String getName() {
        return this.name;
    }

    /**
     * @return this output mode as string.
     */
    @Override
    public String toString() {
        return "Name: " + this.name + " ; Description: " + this.description
               + " ; Mime-Type: " + this.mimeType;
    }

    /**
     * @return the input parameters.
     */
    public Collection<InputValue> getInputParameters() {
        return this.inputParameters;
    }

    /**
     *
     * @return the export modes.
     */
    public List<ExportMode> getExportModes() {
        return exportModes;
    }

}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
